@@ -25,16 +25,24 @@ Widget for the output settings
 
 import gtk
 import gst
+from pitivi.log.loggable import Loggable
+from pitivi.encode import encoders_muxer_compatible, muxer_can_sink_raw_audio, muxer_can_sink_raw_video
 from glade import GladeWidget
-from pitivi.settings import encoders_muxer_compatible, muxer_can_sink_raw_audio, muxer_can_sink_raw_video
 from gstwidget import GstElementSettingsDialog
 
 from gettext import gettext as _
 
-class ExportSettingsWidget(GladeWidget):
+class ExportSettingsWidget(GladeWidget, Loggable):
     glade_file = "exportsettingswidget.glade"
-    video_presets = ( ("DVD PAL",  720,    576,    25.0,        1.0),
-                      ("320x240 @ 30fps", 320,  240,    30.0,        1.0) )
+    video_presets = ((_("576p (PAL DV/DVD)"), 720, 576, 25.0, 1.0),
+                    (_("480p (NTSC DV/DVD)"), 720, 480, 30000.0, 1001.0),
+                    (_("720p HD"), 1280, 720, 30000.0, 1001.0),
+                    (_("1080p full HD"), 1920, 1080, 30000.0, 1001.0),
+                    (_("QVGA (320x240)"), 320, 240, 30.0, 1.0),
+                    (_("VGA (640x480)"), 640, 480, 30.0, 1.0),
+                    (_("SVGA (800x600)"), 800, 600, 30.0, 1.0),
+                    (_("XGA (1024x768)"), 1024, 768, 30.0, 1.0),
+                    )
     video_rates = ( ("12 fps",      12.0, 1.0),
                     ("24 fps",      24.0, 1.0),
                     ("23,97 fps",   24000.0, 1001.0),
@@ -57,14 +65,21 @@ class ExportSettingsWidget(GladeWidget):
 
     def __init__(self):
         GladeWidget.__init__(self)
+        Loggable.__init__(self)
         self.settings = None
         self.validaencoders = []
         self.validvencoders = []
+        # cached values
         self.containersettings = {}
         self.vcodecsettings = {}
         self.acodecsettings = {}
+        self.muxer = None
+        self.vencoder = None
+        self.aencoder = None
+        self._loading = False
 
     def setSettings(self, settings):
+        self.debug("settings:%s", settings)
         self.settings = settings
         self._fillSettings()
 
@@ -86,8 +101,12 @@ class ExportSettingsWidget(GladeWidget):
 
         videolist = self.videocombobox.get_model()
         videolist.clear()
+        fps_map = dict(((num, denom), desc)
+                for desc, num, denom in self.video_rates)
         for preset in self.video_presets:
-            videolist.append([preset[0]])
+            fps = preset[3:5]
+            videolist.append(["%s - %s" % (preset[0], fps_map[fps])])
+
         videolist.append(["Custom"])
 
         # find out from the project settings which combo to take
@@ -157,6 +176,7 @@ class ExportSettingsWidget(GladeWidget):
         self.acodeccbox.set_active(selected)
 
         # Muxer
+        self._loading = True
         self.muxers = self.settings.muxers
         muxs = self.muxercombobox.get_model()
         muxs.clear()
@@ -167,9 +187,13 @@ class ExportSettingsWidget(GladeWidget):
             if mux.get_name() == self.settings.muxer:
                 selected = idx
             idx = idx + 1
+        self._loading = False
         self.muxercombobox.set_active(selected)
 
         # Encoder/Muxer settings
+        self.muxer = self.settings.muxer
+        self.vencoder = self.settings.vencoder
+        self.aencoder = self.settings.aencoder
         self.containersettings = self.settings.containersettings
         self.acodecsettings = self.settings.acodecsettings
         self.vcodecsettings = self.settings.vcodecsettings
@@ -200,9 +224,11 @@ class ExportSettingsWidget(GladeWidget):
 
     def _videoComboboxChangedCb(self, widget):
         idx = widget.get_active()
-        if idx == len(self.video_presets):
+        if idx == -1 or idx == len(self.video_presets):
+            # not a preset
             activate = True
         else:
+            # valid preset
             activate = False
             self.videowidthspin.set_value(self.video_presets[idx][1])
             self.videoheightspin.set_value(self.video_presets[idx][2])
@@ -213,9 +239,11 @@ class ExportSettingsWidget(GladeWidget):
 
     def _audioComboboxChangedCb(self, widget):
         idx = widget.get_active()
-        if idx == len(self.audio_presets):
+        if idx == -1 or idx == len(self.audio_presets):
+            # not a preset
             activate = True
         else:
+            # valid preset
             activate = False
             self.audiochanncbox.set_active(self.audio_presets[idx][1] - 1)
             self._putGoodAudiorate(self.audio_presets[idx][2])
@@ -225,6 +253,9 @@ class ExportSettingsWidget(GladeWidget):
         self.audiodepthcbox.set_sensitive(activate)
 
     def _muxerComboboxChangedCb(self, widget):
+        if self._loading:
+            return
+        # get previous video encoder name
         if self.validvencoders:
             vidx = self.vcodeccbox.get_active()
             if vidx < len(self.validvencoders):
@@ -233,6 +264,8 @@ class ExportSettingsWidget(GladeWidget):
                 prevvenc = None
         else:
             prevvenc = self.settings.vencoder
+
+        # get previous audio encoder name
         if self.validaencoders:
             aidx = self.acodeccbox.get_active()
             if aidx < len(self.validaencoders):
@@ -278,7 +311,7 @@ class ExportSettingsWidget(GladeWidget):
                 selected = idx
         self.acodeccbox.set_active(selected)
 
-    def runSettingsDialog(self, factory, settings):
+    def runSettingsDialog(self, factory, settings={}):
         dialog = GstElementSettingsDialog(factory, settings)
         if dialog.run() == gtk.RESPONSE_OK:
             dialog.hide()
@@ -292,25 +325,37 @@ class ExportSettingsWidget(GladeWidget):
         factory = self.settings.muxers[self.muxercombobox.get_active()]
         if not factory:
             return
-        set = self.runSettingsDialog(factory, self.containersettings)
+        if factory.get_name() == self.settings.muxer:
+            set = self.runSettingsDialog(factory, self.containersettings)
+        else:
+            set = self.runSettingsDialog(factory)
         if set:
             self.containersettings = set
+            self.muxer = factory.get_name()
 
     def _acodecSettingsButtonClickedCb(self, button):
         factory = self.validaencoders[self.acodeccbox.get_active()]
         if not factory:
             return
-        set = self.runSettingsDialog(factory, self.acodecsettings)
+        if factory.get_name() == self.aencoder:
+            set = self.runSettingsDialog(factory, self.acodecsettings)
+        else:
+            set = self.runSettingsDialog(factory)
         if set:
             self.acodecsettings = set
+            self.aencoder = factory.get_name()
 
     def _vcodecSettingsButtonClickedCb(self, button):
         factory = self.validvencoders[self.vcodeccbox.get_active()]
         if not factory:
             return
-        settings = self.runSettingsDialog(factory, self.vcodecsettings)
+        if factory.get_name() == self.vencoder:
+            settings = self.runSettingsDialog(factory, self.vcodecsettings)
+        else:
+            settings = self.runSettingsDialog(factory)
         if settings:
             self.vcodecsettings = settings
+            self.vencoder = factory.get_name()
 
 
     def updateSettings(self):
@@ -335,20 +380,32 @@ class ExportSettingsWidget(GladeWidget):
         elif vidx == len(self.validvencoders):
             vencoder = None
         else:
-            gst.warning("we don't want any video stream")
+            self.warning("we don't want any video stream")
         aidx = self.acodeccbox.get_active()
         if aidx < len(self.validaencoders):
             aencoder = self.validaencoders[aidx].get_name()
         elif aidx == len(self.validaencoders):
             aencoder = None
         else:
-            gst.warning("we don't want any audio stream")
+            self.warning("we don't want any audio stream")
         self.settings.setEncoders(muxer, vencoder, aencoder)
 
         # encoder/muxer settings
-        self.settings.containersettings = self.containersettings
-        self.settings.acodecsettings = self.acodecsettings
-        self.settings.vcodecsettings = self.vcodecsettings
+        # only store cached values if no different factory was chosen.
+        if muxer == self.muxer:
+            self.settings.containersettings = self.containersettings
+        else:
+            self.settings.containersettings = {}
+        if aencoder == self.aencoder:
+            self.settings.acodecsettings = self.acodecsettings
+        else:
+            self.settings.acodecsettings = {}
+        if vencoder == self.vencoder:
+            self.settings.vcodecsettings = self.vcodecsettings
+        else:
+            self.settings.vcodecsettings = {}
+
+        self.debug("Returning %s", self.settings)
 
         return self.settings
 
@@ -367,5 +424,4 @@ class ExportSettingsDialog(gtk.Dialog):
         self.setwidget.show_all()
 
     def getSettings(self):
-        self.setwidget.updateSettings()
-        return self.setwidget.settings
+        return self.setwidget.updateSettings()
