@@ -1,19 +1,19 @@
 import unittest
 import pitivi
-from pitivi.pitivi import Pitivi
+from common import TestCase
+from pitivi.application import Pitivi
 
-class BasicTest(unittest.TestCase):
+class BasicTest(TestCase):
     """
     Basic test to create the proper creation of the Pitivi object
     """
 
     def testBasic(self):
-        ptv = pitivi.pitivi.Pitivi()
+        ptv = Pitivi()
         # was the pitivi object created
         self.assert_(ptv)
 
         # were the contents of pitivi properly created
-        self.assert_(ptv.playground)
         self.assert_(ptv.current)
         self.assert_(ptv.effects)
 
